@@ -7,7 +7,21 @@ function(data, name, dest, lat.lon, overwrite) {
 		lat.lon <- c(which(names(data)==lat.lon[1]), which(names(data)==lat.lon[2]))
 	}
 	if(is.na(data[,lat.lon[1]]) || is.na(data[,lat.lon[2]])) stop("Coordinate columns not found")
-		
+	
+	# check for factors
+	for(i in 1:ncol(data)) {
+		if(is(data[,i], "factor")) {
+			data[,i] <- as.character(data[,i])
+			message("Column '", names(data[i]), "' converted from factor to character type")
+		}
+	}
+	
+	# replace line breaks
+	for(i in 1:ncol(data)) {
+		data[,i] <- gsub("\n","; ",data[,i])
+	}
+	
+	# check file and path
 	path <- paste0(file.path(dest, name), ".geojson")
 	if(file.exists(path) && !overwrite) stop("Abort - file already exists\n")
 	
@@ -26,11 +40,11 @@ function(data, name, dest, lat.lon, overwrite) {
 			cat("      \"properties\": {", file=path, append=TRUE, sep="\n")
 			dat <- data[f,-lat.lon]
 			if(!is.data.frame(dat)) names(dat) <- names(data)[-lat.lon]
-			
+				
 			if(length(dat)==1) {
 				cat(paste0("        \"", names(data)[-lat.lon], "\": \"", dat, "\"\n"), file=path, append=TRUE)
 			} else {
-				for(p in 1:length(dat)) {
+				for(p in 1:length(dat)) {	
 					cat(paste0("        \"", names(dat)[p], "\": \"", dat[p], "\""), file=path, append=TRUE)
 					if(p==length(dat)) cat("\n", file=path, append=TRUE)
 					else cat(",", file=path, append=TRUE, sep="\n")
